@@ -1,25 +1,13 @@
-/* This file is part of the KDE libraries
-    Copyright (c) 1997-1999 Matthias Kalle Dalheimer <kalle@kde.org>
-    Copyright (c) 1997-2000 Matthias Ettrich <ettrich@troll.no>
-    Copyright (c) 1998-2005 Stephan Kulow <coolo@kde.org>
-    Copyright (c) 1999-2004 Waldo Bastian <bastian@kde.org>
-    Copyright (c) 2001-2005 Lubos Lunak <l.lunak@kde.org>
-    Copyright (C) 2008 Aaron Seigo <aseigo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997-1999 Matthias Kalle Dalheimer <kalle@kde.org>
+    SPDX-FileCopyrightText: 1997-2000 Matthias Ettrich <ettrich@troll.no>
+    SPDX-FileCopyrightText: 1998-2005 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1999-2004 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2001-2005 Lubos Lunak <l.lunak@kde.org>
+    SPDX-FileCopyrightText: 2008 Aaron Seigo <aseigo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef _KTOOLINVOCATION_H
@@ -30,9 +18,12 @@
 #include <QObject>
 #include <QByteArray>
 #include <QStringList>
+#include <QExplicitlySharedDataPointer>
 
 class QUrl;
 class KToolInvocationPrivate;
+class KService;
+typedef QExplicitlySharedDataPointer<KService> KServicePtr;
 
 /**
  * @class KToolInvocation ktoolinvocation.h <KToolInvocation>
@@ -97,7 +88,9 @@ public Q_SLOTS:
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use QDesktopServices::openUrl(mailtoURL), using QUrl::setPath(address) and a query item of \"subject\" for the subject")
     static void invokeMailer(const QString &address, const QString &subject,
                              const QByteArray &startup_id = QByteArray());
+#endif
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Invokes the standard email application.
      *
@@ -138,7 +131,7 @@ public Q_SLOTS:
     /**
      * Invokes the user's preferred browser.
      * Note that you should only do this when you know for sure that the browser can
-     * handle the URL (i.e. its mimetype). In doubt, if the URL can point to an image
+     * handle the URL (i.e. its MIME type). In doubt, if the URL can point to an image
      * or anything else than HTML, prefer to use new KRun( url ).
      *
      * See also <a
@@ -156,6 +149,23 @@ public Q_SLOTS:
 #endif
 
     /**
+     * Invokes the standard terminal application.
+     *
+     * @param command the command to execute, can be empty.
+     * @param envs ENV variables for the invoked terminal command
+     * @param workdir the initial working directory, can be empty.
+     * @param startup_id for app startup notification, "0" for none,
+     *           "" ( empty string ) is the default
+     * @since 5.73
+     */
+    static void invokeTerminal(const QString &command,
+                               const QStringList &envs,
+                               const QString &workdir = QString(),
+                               const QByteArray &startup_id = "");
+
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 79)
+    /**
+     *
      * Invokes the standard terminal application.
      *
      * @param command the command to execute, can be empty.
@@ -164,10 +174,23 @@ public Q_SLOTS:
      *           "" ( empty string ) is the default
      *
      * @since 4.1
+     * @deprecated since 5,79, use invokeTerminal(const QString &command, const QStringList &envs, const QString &workdir, const QByteArray &startup_id) instead
      */
+    KSERVICE_DEPRECATED_VERSION(5, 79, "Use invokeTerminal(const QString &command, const QStringList &envs, const QString &workdir, const QByteArray &startup_id) instead")
     static void invokeTerminal(const QString &command,
                                const QString &workdir = QString(),
                                const QByteArray &startup_id = "");
+#endif
+
+   /**
+    * Returns the configured default terminal application. This is compatible with
+    * the old config format from the KCM in Plasma < 5.21.
+    * @param command Command that should be executed in the terminal app
+    * @param workingDir Working directory for the terminal app.
+    * @return KServicePtr of terminal application.
+    * @since 5.78
+    */
+   static KServicePtr terminalApplication(const QString &command = QString(), const QString &workingDir = QString());
 
 public:
 
@@ -197,7 +220,9 @@ public:
     static int startServiceByName(const QString &_name, const QString &URL,
             QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
             const QByteArray &startup_id = QByteArray(), bool noWait = false);
+#endif
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Starts a service based on the (translated) name of the service.
      * E.g. "Web Browser"
@@ -390,7 +415,8 @@ private:
                              const QString &_name, const QStringList &URLs,
                              QString *error, QString *serviceName, int *pid,
                              const QByteArray &startup_id, bool noWait,
-                             const QString &workdir = QString());
+                             const QString &workdir = QString(),
+                             const QStringList &envs = QStringList());
     static bool isMainThreadActive(QString *error = nullptr);
 
     KToolInvocationPrivate *const d;
